// <ACEStransformID>urn:ampas:aces:transformId:v1.5:IDT.Canon.EOSC700_CanonLog_BT2020_TypeD_D55.a1.v1</ACEStransformID>
// <ACESuserName>ACES 1.0 Input - Canon EOS C700 CanonLog BT2020 (TypeD, Daylight)</ACESuserName>

/* ********************************************* */
//
// ACES Input Transform for EOS C700 (Type D)
//
// Input Transform for EOS C700 BT.2020 / Canon Log
// ACES Version: 1.0
// Version: 1.1  2020/06/23
// Copyright(c) 2016 Canon Inc. All Rights Reserved.
//
/* ********************************************* */
//
// Camera      : EOS C700
// Illuminant  : Daylight (CIE Illuminant D55)
// Color Gamut : BT.2020
// Gamma       : Canon Log
// Color Matrix: Neutral
//
// [ NOTE ]
//
// +This Input Transform is defined for images those were shot under daylight
//  and general illumination sources except Tungsten.
//
/* ********************************************* */


/* ============ SUBFUNCTIONS ============ */
/* CanonLog to Linear */
float CanonLog_to_linear (
	float clog
)
{
	float out;

	if(clog < 0.12512248)
		out = -( pow( 10, ( 0.12512248 - clog ) / 0.45310179 ) - 1 ) / 10.1596;
	else
		out = ( pow( 10, ( clog - 0.12512248 ) / 0.45310179 ) - 1 ) / 10.1596;

	return out;
}


/* ============ Main Algorithm ============ */
void main
(   input varying float rIn,
    input varying float gIn,
    input varying float bIn,
    input varying float aIn,
    output varying float rOut,
    output varying float gOut,
    output varying float bOut,
    output varying float aOut
)
{
	// CanonLog to linear 
	float lin[3];
	lin[0] = 0.9 * CanonLog_to_linear( rIn );
	lin[1] = 0.9 * CanonLog_to_linear( gIn );
	lin[2] = 0.9 * CanonLog_to_linear( bIn );
	
	// ACES conversion matrix
	float aces[3];

	aces[0] =   0.678891151 * lin[0] + 0.158868422 * lin[1] + 0.162240427 * lin[2];
	aces[1] =   0.045570831 * lin[0] + 0.860712772 * lin[1] + 0.093716397 * lin[2];
	aces[2] = - 0.000485710 * lin[0] + 0.025060196 * lin[1] + 0.975425515 * lin[2];

	rOut = aces[0];
	gOut = aces[1];
	bOut = aces[2];
	aOut = aIn;
}

/* ============ End of Input Transform ============ */

